@@ -248,7 +248,16 @@ def _is_amora_model(candidate: ModuleType) -> bool:
 @ensure_path
 def amora_model_for_path(path: Path) -> Model:
     try:
-        module = importlib.import_module(path.stem, settings.models_path.name)
+        relative_module_name = (
+            path.relative_to(settings.models_path)
+            .as_posix()
+            .replace("/", ".")
+            .replace(".py", "")
+        )
+
+        module = importlib.import_module(
+            relative_module_name, settings.models_path.name
+        )
     except ModuleNotFoundError as e:
         raise ValueError(f"Invalid path `{path}`") from e
 
@@ -277,6 +286,14 @@ def amora_model_for_name(model_name: str) -> Model:
     raise ValueError(f"{model_name} not found on models list")
 
 
+def amora_model_from_name_list(
+    model_name_list: Iterable[str],
+) -> Iterable[Tuple[Model, Path]]:
+    for model, _path in list_models():
+        if model.unique_name() in model_name_list:
+            yield model, _path
+
+
 def list_models(
     path: Path = settings.models_path,
 ) -> Iterable[Tuple[Model, Path]]:
